@@ -3,7 +3,7 @@
 #
 # Function: Format PDF Output from groff Markup
 #
-# Copyright (C) 2005, 2006, 2009, 2010, Free Software Foundation, Inc.
+# Copyright (C) 2005-2014  Free Software Foundation, Inc.
 # Written by Keith Marshall (keith.d.marshall@ntlworld.com)
 # 
 # This file is part of groff.
@@ -545,7 +545,7 @@
   test "$PDF_OUTPUT" = "$NULLDEV" && exit 0
 #
 # We are now ready to start preparing the intermediate PostScript files,
-# from which the PDF output will be compiled -- but before proceding further ...
+# from which the PDF output will be compiled -- but before proceeding further ...
 # let's make sure we have a GhostScript interpreter to convert them!
 #
   if test -n "$GROFF_GHOSTSCRIPT_INTERPRETER"
@@ -581,6 +581,32 @@
 #
   $AWK '/^grohtml-info/ {print ".pdfhref Z", $2, $3, $4}' $WRKFILE >> $REFCOPY
 #
+# ... appending a dummy map reference, to ensure that at least
+# one such is always present; (this is required, to suppress any
+# further intermediate output to stderr during the "press-ready"
+# runs of groff, for PDF output file production).
+#
+  echo ".pdfhref Z 0 0 0" >> $REFCOPY
+#
+# Evaluate any processing options which may have been specified
+# as a result of parsing the document source ...
+#
+  eval `$SED -n '/^ *pdfroff-option:set */s///p' $WRKFILE`
+#
+# ... (which is currently supported to enable "toc-relocation",
+# only when the document actually relies on it, and if it is not
+# explicitly disabled from the command line) ...
+#
+  if test x${toc_relocation-"auto"} != xenabled
+  then
+#
+#   ... thus we reproduce the effect of the "--no-toc-relocation"
+#   option, when no enabling request is detected in the document
+#   control stream.
+#
+    TC_DATA="" TOC_FORMAT="" BODY_FORMAT=""
+  fi
+#
 # Re-enable progress reporting, if necessary ...
 # (Missing 'awk' or 'diff' may have disabled it, to avoid display
 #  of spurious messages associated with reference resolution).
@@ -653,4 +679,4 @@
   $SAY >&2 ". done"
 #
 # ------------------------------------------------------------------------------
-# $RCSfile: pdfroff.sh,v $ $Revision: 1.18 $: end of file
+# $RCSfile$ $Revision$: end of file
