@@ -1,10 +1,8 @@
-#!@PERLPATH@ -w
+#!@PERL@ -w
 #
 #	gropdf		: PDF post processor for groff
-#	Deri James	: 4th May 2009
 #
-
-# Copyright (C) 2011, 2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2014  Free Software Foundation, Inc.
 #      Written by Deri James <deri@chuzzlewit.demon.co.uk>
 #
 # This file is part of groff.
@@ -56,6 +54,8 @@ my $stream='';	# Current Text/Graphics stream
 my $cftsz=10;	# Current font sz
 my $cft;	# Current Font
 my $lwidth=1;	# current linewidth
+my $linecap=1;
+my $linejoin=1;
 my $textcol='';	# Current groff text
 my $fillcol='';	# Current groff fill
 my $curfill='';	# Current PDF fill
@@ -693,10 +693,23 @@ sub do_x
 		$stream.="Q\n";
 		$InPicRotate=0;
 	    }
+	    elsif ($par=~m/exec (\d) setlinejoin/)
+	    {
+		IsGraphic();
+		$linejoin=$1;
+		$stream.="$linejoin j\n";
+	    }
+	    elsif ($par=~m/exec (\d) setlinecap/)
+	    {
+		IsGraphic();
+		$linecap=$1;
+		$stream.="$linecap J\n";
+	    }
 	    elsif ($par=~m/\[(.+) pdfmark/)
 	    {
 		my $pdfmark=$1;
 		$pdfmark=~s((\d{4,6}) u)(sprintf("%.1f",$1/$desc{sizescale}))eg;
+		$pdfmark=~s(\\\[u00(..)\])(chr(hex($1)))eg;
 
 		if ($pdfmark=~m/(.+) \/DOCINFO/)
 		{
@@ -892,8 +905,8 @@ sub do_x
 	    elsif (lc($xprm[1]) eq 'pdfpic')
 	    {
 		my $fil=$xprm[2];
-		my $flag=uc($xprm[3]);
-		my $wid=GetPoints($xprm[4]);
+		my $flag=uc($xprm[3])||'-L';
+		my $wid=GetPoints($xprm[4])||-1;
 		my $hgt=GetPoints($xprm[5]||-1);
 		my $ll=GetPoints($xprm[6]||0);
 		my $mat=[1,0,0,1,0,0];
@@ -907,6 +920,7 @@ sub do_x
 		{
 		    IsGraphic();
 		    my $bbox=$incfil{$fil}->[1];
+		    $wid=($bbox->[2]-$bbox->[0]) if $wid <= 0;
 		    my $xscale=$wid/($bbox->[2]-$bbox->[0]);
 		    my $yscale=($hgt<=0)?$xscale:($hgt/($bbox->[3]-$bbox->[1]));
 		    $xscale=($wid<=0)?$yscale:$xscale;
@@ -917,11 +931,11 @@ sub do_x
 
 		    if ($flag eq '-C' and $ll > $wid)
 		    {
-			$xpos+=int(($ll-$wid)/2);
+			$xpos=int(($ll-$wid)/2);
 		    }
 		    elsif ($flag eq '-R' and $ll > $wid)
 		    {
-			$xpos+=$ll-$wid;
+			$xpos=$ll-$wid;
 		    }
 
 		    $ypos+=$hgt;
@@ -1110,6 +1124,7 @@ sub PutHotSpot
     $l=~s/Color/C/;
     $l=~s/Action/A/;
     $l=~s'/Subtype /URI'/S /URI';
+    $l=~s(\\\[u00(..)\])(chr(hex($1)))eg;
     my @xwds=split(' ',"<< $l >>");
     my $annotno=BuildObj(++$objct,ParsePDFValue(\@xwds));
     my $annot=$obj[$objct];
@@ -1270,10 +1285,10 @@ sub LoadSWF
 sub LoadPDF
 {
     my $pdfnm=shift;
+    my $mat=shift;
     my $wid=shift;
     my $hgt=shift;
     my $type=shift;
-    my $mat=[1,0,0,1,0,0];
     my $pdf;
     my $pdftxt='';
     my $strmlen=0;
@@ -1411,8 +1426,9 @@ sub LoadPDF
 
     $BBox=[0,0,595,842] if !defined($BBox);
 
-    my $xscale=$wid/($BBox->[2]-$BBox->[0]+1);
-    my $yscale=($hgt<=0)?$xscale:($hgt/($BBox->[3]-$BBox->[1]+1));
+    $wid=($BBox->[2]-$BBox->[0]+1) if $wid==0;
+    my $xscale=abs($wid)/($BBox->[2]-$BBox->[0]+1);
+    my $yscale=($hgt<=0)?$xscale:(abs($hgt)/($BBox->[3]-$BBox->[1]+1));
     $hgt=($BBox->[3]-$BBox->[1]+1)*$yscale;
 
     if ($type eq "import")
@@ -1606,7 +1622,7 @@ sub nextwd
 
     return('') if !defined($wd);
 
-    if ($wd=~m/^(.*?)(<<|>>|\[|\])(.*)/)
+    if ($wd=~m/^(.*?)(<<|>>|(?:(?<!\\)\[|\]))(.*)/)
     {
 	if (defined($1) and length($1))
 	{
@@ -2309,7 +2325,8 @@ sub do_p
     $objct+=1;
     $cpage=$obj[$cpageno]->{DATA};
     $pages->{'Count'}++;
-    $stream="q 1 0 0 1 0 0 cm\n";
+    $stream="q 1 0 0 1 0 0 cm\n$linejoin J\n$linecap j\n";
+    $stream.=$strkcol."\n", $curstrk=$strkcol if $strkcol ne '';
     $mode='g';
     $curfill='';
 #    @mediabox=@defaultmb;
@@ -2418,10 +2435,23 @@ sub do_s
     {
 	PutLine();
 	$cftsz=$par;
+	Set_LWidth() if $lwidth < 1;
 #		$stream.="/F$cft $cftsz Tf\n";
 	$fontchg=1;
 	$widtbl=CacheWid($cft);
     }
+    else
+    {
+	$cftsz=$par;
+	Set_LWidth() if $lwidth < 1;
+    }
+}
+
+sub Set_LWidth
+{
+    IsGraphic();
+    $stream.=((($desc{res}/(72*$desc{sizescale}))*$linewidth*$cftsz)/1000)." w\n";
+    return;
 }
 
 sub do_m
@@ -2577,7 +2607,7 @@ sub do_D
     }
     elsif ($Dcmd eq 'p' or $Dcmd eq 'P')
     {
-	# B-Spline
+	# Polygon
 	my (@p)=split(' ',$par);
 	my ($nxpos,$nypos);
 
@@ -3039,7 +3069,7 @@ sub do_t
     $xpos+=($pendmv-$nomove)/$unitwidth;
 
     $stream.="% == '$par'=$wid 'xpos=$xpos\n" if $debug;
-    $par=~s/\\/\\\\/g;
+    $par=~s/\\(?!\d\d\d)/\\\\/g;
     $par=~s/\)/\\)/g;
     $par=~s/\(/\\(/g;
 
@@ -3169,7 +3199,7 @@ sub FindChar
 	my $ch=$fnt->{GNM}->{$chnm};
 	$ch=RemapChr($ch,$fnt,$chnm) if ($ch > 255);
 
-	return(chr($ch),$fnt->{WID}->[$ch]*$cftsz);
+	return(($ch<32)?sprintf("\\%03o",$ch):chr($ch),$fnt->{WID}->[$ch]*$cftsz);
     }
     else
     {
@@ -3245,3 +3275,11 @@ sub do_n
     @lin=();
     PutHotSpot($xpos) if defined($mark);
 }
+
+
+1;
+########################################################################
+### Emacs settings
+# Local Variables:
+# mode: CPerl
+# End:
