@@ -2,13 +2,10 @@
 
 // <groff_src_dir>/src/libs/libdriver/input.cpp
 
-/* Copyright (C) 1989-1992, 2001-2006, 2008-2011
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
 
    Written by James Clark (jjc@jclark.com)
-   Major rewrite 2001 by Bernd Warken (bwarken@mayn.de)
-
-   Last update: 9 May 2010
+   Major rewrite 2001 by Bernd Warken <groff-bernd.warken-72@web.de>
 
    This file is part of groff, the GNU roff text processing system.
 
