@@ -2,13 +2,9 @@
 
 // <groff_src_dir>/src/libs/libdriver/printer.cpp
 
-/* Copyright (C) 1989, 1990, 1991, 1992, 2001, 2002, 2003, 2004, 2005,
-                 2006, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
    Written by James Clark (jjc@jclark.com)
 
-   Last update: 5 Jan 2009
-
    This file is part of groff.
 
    groff is free software; you can redistribute it and/or modify it
