@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,76 +26,84 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     OVER = 258,
-     SMALLOVER = 259,
-     SQRT = 260,
-     SUB = 261,
-     SUP = 262,
-     LPILE = 263,
-     RPILE = 264,
-     CPILE = 265,
-     PILE = 266,
-     LEFT = 267,
-     RIGHT = 268,
-     TO = 269,
-     FROM = 270,
-     SIZE = 271,
-     FONT = 272,
-     ROMAN = 273,
-     BOLD = 274,
-     ITALIC = 275,
-     FAT = 276,
-     ACCENT = 277,
-     BAR = 278,
-     UNDER = 279,
-     ABOVE = 280,
-     TEXT = 281,
-     QUOTED_TEXT = 282,
-     FWD = 283,
-     BACK = 284,
-     DOWN = 285,
-     UP = 286,
-     MATRIX = 287,
-     COL = 288,
-     LCOL = 289,
-     RCOL = 290,
-     CCOL = 291,
-     MARK = 292,
-     LINEUP = 293,
-     TYPE = 294,
-     VCENTER = 295,
-     PRIME = 296,
-     SPLIT = 297,
-     NOSPLIT = 298,
-     UACCENT = 299,
-     SPECIAL = 300,
-     SPACE = 301,
-     GFONT = 302,
-     GSIZE = 303,
-     DEFINE = 304,
-     NDEFINE = 305,
-     TDEFINE = 306,
-     SDEFINE = 307,
-     UNDEF = 308,
-     IFDEF = 309,
-     INCLUDE = 310,
-     DELIM = 311,
-     CHARTYPE = 312,
-     SET = 313,
-     GRFONT = 314,
-     GBFONT = 315
-   };
+  enum yytokentype
+  {
+    OVER = 258,
+    SMALLOVER = 259,
+    SQRT = 260,
+    SUB = 261,
+    SUP = 262,
+    LPILE = 263,
+    RPILE = 264,
+    CPILE = 265,
+    PILE = 266,
+    LEFT = 267,
+    RIGHT = 268,
+    TO = 269,
+    FROM = 270,
+    SIZE = 271,
+    FONT = 272,
+    ROMAN = 273,
+    BOLD = 274,
+    ITALIC = 275,
+    FAT = 276,
+    ACCENT = 277,
+    BAR = 278,
+    UNDER = 279,
+    ABOVE = 280,
+    TEXT = 281,
+    QUOTED_TEXT = 282,
+    FWD = 283,
+    BACK = 284,
+    DOWN = 285,
+    UP = 286,
+    MATRIX = 287,
+    COL = 288,
+    LCOL = 289,
+    RCOL = 290,
+    CCOL = 291,
+    MARK = 292,
+    LINEUP = 293,
+    TYPE = 294,
+    VCENTER = 295,
+    PRIME = 296,
+    SPLIT = 297,
+    NOSPLIT = 298,
+    UACCENT = 299,
+    SPECIAL = 300,
+    SPACE = 301,
+    GFONT = 302,
+    GSIZE = 303,
+    DEFINE = 304,
+    NDEFINE = 305,
+    TDEFINE = 306,
+    SDEFINE = 307,
+    UNDEF = 308,
+    IFDEF = 309,
+    INCLUDE = 310,
+    DELIM = 311,
+    CHARTYPE = 312,
+    SET = 313,
+    GRFONT = 314,
+    GBFONT = 315
+  };
 #endif
 /* Tokens.  */
 #define OVER 258
@@ -157,15 +165,12 @@
 #define GRFONT 314
 #define GBFONT 315
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 31 "eqn.y"
+#line 30 "eqn.y" /* yacc.c:1909  */
 
 	char *str;
 	box *b;
@@ -174,16 +179,15 @@ typedef union YYSTYPE
 	int n;
 	column *col;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 181 "y.tab.h"
-} YYSTYPE;
+#line 183 "y.tab.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
