@@ -1,22 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2003 Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "pic.h"
 #include "common.h"
@@ -319,9 +318,10 @@ void common_output::solid_arc(const position &cent, double rad,
 
 
 void common_output::rounded_box(const position &cent, const distance &dim,
-				double rad, const line_type &lt, double fill)
+				double rad, const line_type &lt,
+			        double fill, char *color_fill)
 {
-  if (fill >= 0.0)
+  if (fill >= 0.0 || color_fill)
     filled_rounded_box(cent, dim, rad, fill);
   switch (lt.type) {
   case line_type::invisible:
