@@ -1,7 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002, 2003, 2005,
-                 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -462,7 +460,7 @@ void troff_output::text(const position &center, text_piece *v, int n,
       fputs("\n.sp -1\n", stdout);
     }
   if (rotate_flag)
-    printf(".if '\\*(.T'ps' \\{\\\n"
+    printf(".if \\n(" GROPS_REG " \\{\\\n"
 	   "\\X'ps: exec grestore'\n.sp -1\n"
 	   ".\\}\n");
 }
