@@ -1,23 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-1992, 2000, 2001, 2003, 2004, 2005
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 51 Franklin St - Fifth Floor, Boston, MA 02110-1301, USA. */
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "lib.h"
 
@@ -40,12 +38,12 @@ int tex_flag = 0;
 
 extern "C" const char *Version_string;
 
-int do_file(const char *filename);
+int do_file(const char *);
 
 
 void usage(FILE *stream)
 {
-  fprintf(stream, "usage: %s [ -Crtv ] [ -I file ] [ files ]\n", program_name);
+  fprintf(stream, "usage: %s [ -Crtv ] [ -I dir ] [ files ]\n", program_name);
 }
 
 int main(int argc, char **argv)
@@ -60,11 +58,9 @@ int main(int argc, char **argv)
   while ((opt = getopt_long(argc, argv, "CI:rtv", long_options, NULL)) != EOF)
     switch (opt) {
     case 'v':
-      {
-	printf("GNU soelim (groff) version %s\n", Version_string);
-	exit(0);
-	break;
-      }
+      printf("GNU soelim (groff) version %s\n", Version_string);
+      exit(0);
+      break;
     case 'C':
       compatible_flag = 1;
       break;
@@ -101,8 +97,8 @@ int main(int argc, char **argv)
 
 void set_location()
 {
-  if(!raw_flag) {
-    if(!tex_flag)
+  if (!raw_flag) {
+    if (!tex_flag)
       printf(".lf %d %s\n", current_lineno, current_filename);
     else
       printf("%% file %s, line %d\n", current_filename, current_lineno);
