@@ -1,23 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002, 2003, 2004, 2005
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 51 Franklin St - Fifth Floor, Boston, MA 02110-1301, USA. */
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "table.h"
 
@@ -498,6 +496,11 @@ options *process_options(table_input &in)
 	error("`nospaces' option does not take an argument");
       opt->flags |= table::NOSPACES;
     }
+    else if (strieq(p, "nowarn")) {
+      if (arg)
+	error("`nowarn' option does not take an argument");
+      opt->flags |= table::NOWARN;
+    }
     else if (strieq(p, "decimalpoint")) {
       if (!arg)
 	error("`decimalpoint' option requires argument in parentheses");
@@ -508,6 +511,9 @@ options *process_options(table_input &in)
 	  opt->decimal_point_char = arg[0];
       }
     }
+    else if (strieq(p, "experimental")) {
+      opt->flags |= table::EXPERIMENTAL;
+    }
     else {
       error("unrecognised global option `%1'", p);
       // delete opt;
@@ -619,6 +625,7 @@ struct format {
   int *separation;
   string *width;
   char *equal;
+  char *expand;
   entry_format **entry;
   char **vline;
 
@@ -635,8 +642,11 @@ format::format(int nr, int nc) : nrows(nr), ncolumns(nc)
     separation[i] = -1;
   width = new string[ncolumns];
   equal = new char[ncolumns];
-  for (i = 0; i < ncolumns; i++)
+  expand = new char[ncolumns];
+  for (i = 0; i < ncolumns; i++) {
     equal[i] = 0;
+    expand[i] = 0;
+  }
   entry = new entry_format *[nrows];
   for (i = 0; i < nrows; i++)
     entry[i] = new entry_format[ncolumns];
@@ -676,6 +686,7 @@ format::~format()
   a_delete separation;
   ad_delete(ncolumns) width;
   a_delete equal;
+  a_delete expand;
   for (int i = 0; i < nrows; i++) {
     a_delete vline[i];
     ad_delete(ncolumns) entry[i];
@@ -692,6 +703,7 @@ struct input_entry_format : public entry_format {
   int pre_vline;
   int last_column;
   int equal;
+  int expand;
   input_entry_format(format_type, input_entry_format * = 0);
   ~input_entry_format();
   void debug_print();
@@ -705,6 +717,7 @@ input_entry_format::input_entry_format(format_type t, input_entry_format *p)
   vline = 0;
   pre_vline = 0;
   equal = 0;
+  expand = 0;
 }
 
 input_entry_format::~input_entry_format()
@@ -734,6 +747,8 @@ void input_entry_format::debug_print()
   }
   if (equal)
     putc('e', stderr);
+  if (expand)
+    putc('x', stderr);
   if (separation >= 0)
     fprintf(stderr, "%d", separation); 
   for (i = 0; i < vline; i++)
@@ -750,6 +765,7 @@ format *process_format(table_input &in, options *opt,
 		       format *current_format = 0)
 {
   input_entry_format *list = 0;
+  int have_expand = 0;
   int c = in.get();
   for (;;) {
     int pre_vline = 0;
@@ -837,26 +853,6 @@ format *process_format(table_input &in, options *opt,
     int success = 1;
     do {
       switch (c) {
-      case 't':
-      case 'T':
-	c = in.get();
-	list->vertical_alignment = entry_modifier::TOP;
-	break;
-      case 'd':
-      case 'D':
-	c = in.get();
-	list->vertical_alignment = entry_modifier::BOTTOM;
-	break;
-      case 'u':
-      case 'U':
-	c = in.get();
-	list->stagger = 1;
-	break;
-      case 'z':
-      case 'Z':
-	c = in.get();
-	list->zero_width = 1;
-	break;
       case '0':
       case '1':
       case '2':
@@ -876,6 +872,23 @@ format *process_format(table_input &in, options *opt,
 	  list->separation = w;
 	}
 	break;
+      case 'B':
+      case 'b':
+	c = in.get();
+	list->font = "B";
+	break;
+      case 'd':
+      case 'D':
+	c = in.get();
+	list->vertical_alignment = entry_modifier::BOTTOM;
+	break;
+      case 'e':
+      case 'E':
+	c = in.get();
+	list->equal = 1;
+	// `e' and `x' are mutually exclusive
+	list->expand = 0;
+	break;
       case 'f':
       case 'F':
 	do {
@@ -910,8 +923,13 @@ format *process_format(table_input &in, options *opt,
 	  }
 	}
 	break;
-      case 'x':
-      case 'X':
+      case 'I':
+      case 'i':
+	c = in.get();
+	list->font = "I";
+	break;
+      case 'm':
+      case 'M':
 	do {
 	  c = in.get();
 	} while (c == ' ' || c == '\t');
@@ -944,33 +962,6 @@ format *process_format(table_input &in, options *opt,
 	  }
 	}
 	break;
-      case 'v':
-      case 'V':
-	c = in.get();
-	list->vertical_spacing.val = 0;
-	list->vertical_spacing.inc = 0;
-	if (c == '+' || c == '-') {
-	  list->vertical_spacing.inc = (c == '+' ? 1 : -1);
-	  c = in.get();
-	}
-	if (c == EOF || !csdigit(c)) {
-	  error("`v' modifier must be followed by number");
-	  list->vertical_spacing.inc = 0;
-	}
-	else {
-	  do {
-	    list->vertical_spacing.val *= 10;
-	    list->vertical_spacing.val += c - '0';
-	    c = in.get();
-	  } while (c != EOF && csdigit(c));
-	}
-	if (list->vertical_spacing.val > MAX_VERTICAL_SPACING
-	    || list->vertical_spacing.val < -MAX_VERTICAL_SPACING) {
-	  error("unreasonable vertical spacing");
-	  list->vertical_spacing.val = 0;
-	  list->vertical_spacing.inc = 0;
-	}
-	break;
       case 'p':
       case 'P':
 	c = in.get();
@@ -998,6 +989,43 @@ format *process_format(table_input &in, options *opt,
 	  list->point_size.inc = 0;
 	}
 	break;
+      case 't':
+      case 'T':
+	c = in.get();
+	list->vertical_alignment = entry_modifier::TOP;
+	break;
+      case 'u':
+      case 'U':
+	c = in.get();
+	list->stagger = 1;
+	break;
+      case 'v':
+      case 'V':
+	c = in.get();
+	list->vertical_spacing.val = 0;
+	list->vertical_spacing.inc = 0;
+	if (c == '+' || c == '-') {
+	  list->vertical_spacing.inc = (c == '+' ? 1 : -1);
+	  c = in.get();
+	}
+	if (c == EOF || !csdigit(c)) {
+	  error("`v' modifier must be followed by number");
+	  list->vertical_spacing.inc = 0;
+	}
+	else {
+	  do {
+	    list->vertical_spacing.val *= 10;
+	    list->vertical_spacing.val += c - '0';
+	    c = in.get();
+	  } while (c != EOF && csdigit(c));
+	}
+	if (list->vertical_spacing.val > MAX_VERTICAL_SPACING
+	    || list->vertical_spacing.val < -MAX_VERTICAL_SPACING) {
+	  error("unreasonable vertical spacing");
+	  list->vertical_spacing.val = 0;
+	  list->vertical_spacing.inc = 0;
+	}
+	break;
       case 'w':
       case 'W':
 	c = in.get();
@@ -1033,26 +1061,27 @@ format *process_format(table_input &in, options *opt,
 	    } while (c != EOF && csdigit(c));
 	  }
 	}
+	// `w' and `x' are mutually exclusive
+	list->expand = 0;
 	break;
-      case 'e':
-      case 'E':
+      case 'x':
+      case 'X':
 	c = in.get();
-	list->equal++;
+	list->expand = 1;
+	// `x' and `e' are mutually exclusive
+	list->equal = 0;
+	// `x' and `w' are mutually exclusive
+	list->width = "";
+	break;
+      case 'z':
+      case 'Z':
+	c = in.get();
+	list->zero_width = 1;
 	break;
       case '|':
 	c = in.get();
 	list->vline++;
 	break;
-      case 'B':
-      case 'b':
-	c = in.get();
-	list->font = "B";
-	break;
-      case 'I':
-      case 'i':
-	c = in.get();
-	list->font = "I";
-	break;
       case ' ':
       case '\t':
 	c = in.get();
@@ -1139,7 +1168,7 @@ format *process_format(table_input &in, options *opt,
   col = 0;
   for (tem = list; tem; tem = tem->next) {
     f->entry[row][col] = *tem;
-    if (col < ncolumns-1) {
+    if (col < ncolumns - 1) {
       // use the greatest separation
       if (tem->separation > f->separation[col]) {
 	if (current_format)
@@ -1156,17 +1185,25 @@ format *process_format(table_input &in, options *opt,
       else
 	f->equal[col] = 1;
     }
+    if (tem->expand && !f->expand[col]) {
+      if (current_format)
+	error("cannot change which columns are expanded in continued format");
+      else {
+	f->expand[col] = 1;
+	have_expand = 1;
+      }
+    }
     if (!tem->width.empty()) {
       // use the last width
       if (!f->width[col].empty() && f->width[col] != tem->width)
-	error("multiple widths for column %1", col+1);
+	error("multiple widths for column %1", col + 1);
       f->width[col] = tem->width;
     }
     if (tem->pre_vline) {
       assert(col == 0);
       f->vline[row][col] = tem->pre_vline;
     }
-    f->vline[row][col+1] = tem->vline;
+    f->vline[row][col + 1] = tem->vline;
     if (tem->last_column) {
       row++;
       col = 0;
@@ -1176,7 +1213,7 @@ format *process_format(table_input &in, options *opt,
   }
   free_input_entry_format_list(list);
   for (col = 0; col < ncolumns; col++) {
-    entry_format *e = f->entry[f->nrows-1] + col;
+    entry_format *e = f->entry[f->nrows - 1] + col;
     if (e->type != FORMAT_HLINE
 	&& e->type != FORMAT_DOUBLE_HLINE
 	&& e->type != FORMAT_SPAN)
@@ -1187,6 +1224,10 @@ format *process_format(table_input &in, options *opt,
     delete f;
     return 0;
   }
+  if (have_expand && (opt->flags & table::EXPAND)) {
+    error("ignoring global `expand' option because of `x' specifiers");
+    opt->flags &= ~table::EXPAND;
+  }
   return f;
 }
 
@@ -1487,6 +1528,9 @@ table *process_data(table_input &in, format *f, options *opt)
   for (i = 0; i < ncolumns; i++)
     if (f->equal[i])
       tbl->set_equal_column(i);
+  for (i = 0; i < ncolumns; i++)
+    if (f->expand[i])
+      tbl->set_expand_column(i);
   return tbl;
 }
 
