@@ -1,5 +1,4 @@
-/* Copyright (C) 1989-1992, 2000, 2002, 2005, 2009, 2011
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -23,8 +22,9 @@ extern "C" {
 }
 #endif
 
-/* run_pipeline can handle at most this many commands */
-#define MAX_COMMANDS 14
+/* run_pipeline can handle at most this many commands,
+   see the const numbers in groff.cpp */
+#define MAX_COMMANDS 15
 
 /* Children exit with this status if execvp fails. */
 #define EXEC_FAILED_EXIT_STATUS 0xff
